@@ -11,6 +11,7 @@ import logging
 import argparse
 import re
 import pydoc
+import shutil 
 
 from urllib.parse import urlparse
 from collections import OrderedDict
@@ -68,8 +69,9 @@ def cli_pager(text):
 def get_cli_pager():
     if sys.platform == 'win32':
         return lambda text: pydoc.pipepager(text, 'more /C')
-    if hasattr(os, 'system') and os.system('(less) 2>/dev/null') == 0:
+    if shutil.which('less') is not None:
         return lambda text: pydoc.pipepager(text, 'less -R')
+    return lambda text: print(text)
 
 class AlertLogicCLI(object):
     def __init__(self):
@@ -197,7 +199,9 @@ class ServiceOperation(object):
             # Remove optional arguments that haven't been supplied
             op_args = {k:self._encode(operation, k, v) for (k,v) in kwargs.items() if v is not None}
             res = operation(**op_args)
-            if res.headers.get('content-type') == 'text/plain':
+            content_type = res.headers.get('content-type')
+            json_content_types = ['application/json', 'alertlogic/json']
+            if content_type and content_type not in json_content_types:
                 print(res.text)
             else:
                 try:
@@ -282,7 +286,14 @@ class ServiceOperation(object):
                 try:
                     return json.loads(param_value)
                 except JSONDecodeError as e:
-                    logging.error(f"{e}")
+                    import textwrap
+                    bad_input_lines = param_value.split('\n')
+                    bad_input_lines.insert(e.lineno, ' ' * (e.colno - 1) + "^ ERROR")
+                    explainer = '\n'.join(bad_input_lines)
+                    explainer = textwrap.indent(explainer, '    ')
+                    logger.error(f"Unable to parse input as JSON.  "
+                                 f"Line {e.lineno}, column {e.colno}: {e.msg}\n"
+                                 f"Input:\n{explainer}\nFalling back to using the input as a string.")
 
         if parameter_type in OpenAPIKeyWord.OBJECT:
             try:
@@ -298,7 +309,10 @@ class ServiceOperation(object):
                     (m.groupdict()['key'], m.groupdict()['value'])
                     for m in regex.finditer(param_value)
                 )
-                return result
+                if result:
+                    return result
+                else:
+                    return param_value
 
         # TODO Raise an exception if we can't build a dictionary from the provided input
         return param_value
