@@ -6,6 +6,7 @@ import os
 import json
 import textwrap
 import itertools
+import shutil
 from almdrlib.session import Session
 from almdrlib.region import Region
 from almdrlib.region import Residency
@@ -42,11 +43,7 @@ def get_param_type(spec):
                 f'Unsupported parameter type. {json.dumps(spec, indent=2)}')
 
 class FormatHelp:
-    if sys.platform == 'win32':
-        BOLD = ''
-        UNDERLINE = ''
-        END = ''
-    elif hasattr(os, 'system') and os.system('(less) 2>/dev/null') == 0:
+    if shutil.which('less') is not None:
         BOLD = '\033[1m'
         UNDERLINE = '\033[4m'
         END = '\033[0m'
@@ -116,7 +113,7 @@ class ALCliHelpFormatter():
         yield f'{title}'
         yield FormatHelp.SECTION_BREAK
         yield f'{self.bold("NAME")}'
-        yield f'\t{self.name} - '
+        yield f'\t{self.name}'
         yield ''
 
         
@@ -368,11 +365,11 @@ class ALCliOperationHelpFormatter(ALCliHelpFormatter):
             properties = spec.get('properties', {})
             for prop_name, prop_spec in sorted(properties.items()):
                 yield ''
-                prop_title = (
-                        f'o {self.bold(prop_name)} - '
-                        f'{prop_spec.get("description", "")}'
-                    )
-
+                prop_desc = prop_spec.get("description")
+                if prop_desc:
+                    prop_title = f'o {self.bold(prop_name)} - 'f'{prop_desc}'
+                else:
+                    prop_title = f'o {self.bold(prop_name)}'
                 yield from self.wraptext(
                         prop_title,
                         initial_indent=indent,
@@ -418,9 +415,14 @@ class ALCliOperationHelpFormatter(ALCliHelpFormatter):
 
         for s in spec:
             yield ''
-            title = self.bold(s.get('title')) + \
-                    f' ({get_param_type(s)}) - ' + \
-                    s.get('description')
+            param_title = s.get('title')
+            param_desc = s.get('description')
+            if param_title and param_desc:
+                title = self.bold(param_title) + f' ({get_param_type(s)}) - ' + param_desc
+            elif param_title:
+                title = self.bold(param_title) + f' ({get_param_type(s)})'
+            else:
+                title = f'({get_param_type(s)})'
             yield from self.wraptext(
                     title,
                     initial_indent=indent,
